pub trait HDbcWrapper<'env>: DerefMut<Target = HDbc<'env>> {
type Handle: HDbcWrapper<'env>;
// Required methods
fn into_hdbc(self) -> HDbc<'env>;
fn from_hdbc(handle: HDbc<'env>) -> Self::Handle;
}Expand description
Implemented by Connected and Unconnected.
There are two implementations of this trait. These two implementations only decide wether or
not a disconnect should be executed on drop. This trait allows to handle them both in generic
code and makes them syntactically very similar to a direct use of HDbc.
Required Associated Types
Sourcetype Handle: HDbcWrapper<'env>
type Handle: HDbcWrapper<'env>
Type to a handle, which also must implement this trait.
Required Methods
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".